<script setup>
import {computed, onMounted} from "vue";

	const props = defineProps({
		visible: {
			type: Boolean,
			default: false,
		},
		name: {
			type: String,
			default: ""
		},
		cWidth: {
			type: Number,
			default: 100
		},
		cHeight: {
			type: Number,
			default: 100,
		},
		dWidth: {
			type: Number,
			default: 100
		},
		dHeight: {
			type: Number,
			default: 100
		},
		x: {
			type: Number,
			default: 0
		},
		y: {
			type: Number,
			default: 0
		},
		info: {
			type: Object,
			default() {
				return {
					tmp: 0,
					hum: 0,
					diff: 0
				}
			}
		}
	});

	const posStyle = computed(()=>{
		return {
			left: props.x*props.cWidth/props.dWidth+'px',
			top: props.y*props.cHeight/props.dHeight+'px'
		}
	});
</script>

<template>
	<div class="map-pin" :style="posStyle">
		<el-tooltip placement="top" :visible="visible">
			<template #content>
				<div class="home-info name">{{name}}</div>
				<div class="home-info">温度：{{ info.tmp }} ℃</div>
				<div class="home-info">湿度：{{ info.hum }} %RH</div>
				<div class="home-info">压差：{{ info.diff }} Pa</div>
			</template>
			<div class="map-pin-content">
					<div class="pin"></div>
					<div class="pulse"></div>
			</div>
		</el-tooltip>
	</div>
</template>

<style lang="less" scoped>
@size: 24px;
.map-pin {
	position: absolute;
	cursor: pointer;
	z-index: 1;
	.map-pin-content {
		position: relative;
		top: -@size - @size*0.1;
		left: -@size*0.5;
		.pin {
			width: @size;
			height: @size;
			border-radius: 50% 50% 50% 0;
			background-color: @font-color-high-light;
			transform: rotate(-45deg);
			&:hover {
				background-color: @font-color-primary;
			}
			&:active {
				background-color: @font-color-warning;
			}
			&:after {
				content: '';
				position: absolute;
				width: @size*0.5;
				height: @size*0.5;
				margin: @size*0.25 0 0 @size*0.25;
				background: #646767;
				border-radius: 50%;
			}
		}
		.pulse {
			position: absolute;
			background: rgba(0, 254, 255, 0.3);
			border-radius: 50%;
			height: @size*0.8;
			width: @size*0.8;
			margin-left: @size*0.1;
			margin-top: -@size*0.2;
			transform: rotateX(55deg);
		}
	}
}
.home-info {
	&.name {
		text-align: center;
	}
}
</style>
